==> modlogan_0.7.12.orig.tar.gz: modlogan-0.7.12.orig/src/input/qmail/plugin_config.h <==
/*
** Modular Logfile Analyzer
** Copyright 2000 Jan Kneschke <jan@kneschke.de>
**
** Homepage: http://www.kneschke.de/projekte/modlogan
**

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version, and provided that the above
    copyright and permission notice is included with all distributed
    copies of this or derived software.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA

**
** $Id: plugin_config.h,v 1.3 2001/12/30 23:05:44 ostborn Exp $
*/
#ifndef _INPUT_PLUGIN_CONFIG_H_
#define _INPUT_PLUGIN_CONFIG_H_

#include <stdio.h>
#include <pcre.h>

#include "mconfig.h"
#include "mrecord.h"

typedef struct {
	FILE	*inputfile;
	char	*inputfilename;

	char	*buffer;
	int	buf_len;
	int	buf_inc;

	pcre	*match_qmail_syslog_pre,
		*match_qmail_new,
		*match_qmail_end,
		*match_qmail_delivery,
		*match_qmail_status,
		*match_qmail_starting,
		*match_qmail_info,
		*match_qmail_bounce,
		*match_qmail_status_smtp,
		*match_qmail_status_dsn,
		*match_qmail_triple_bounce;
} config_input;

int mplugins_input_qmail_get_next_record(mconfig *ext_conf, mlogrec *record);

#endif

==> modlogan_0.8.13.orig.tar.gz: modlogan-0.8.13/src/input/qmail/plugin_config.h <==
/*
** Modular Logfile Analyzer
** Copyright 2000 Jan Kneschke <jan@kneschke.de>
**
** Homepage: http://www.modlogan.org
**

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version, and provided that the above
    copyright and permission notice is included with all distributed
    copies of this or derived software.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA

**
** $Id: plugin_config.h,v 1.7 2003/04/18 18:38:14 ostborn Exp $
*/
#ifndef _INPUT_PLUGIN_CONFIG_H_
#define _INPUT_PLUGIN_CONFIG_H_

#include <pcre.h>

#include "mio.h"

#include "mconfig.h"
#include "mrecord.h"

typedef struct {
	char	*inputfilename;
	
	mfile	inputfile;
	buffer	*buf;

	pcre	*match_qmail_syslog_pre,
		*match_qmail_tai64n_timestamp,
		*match_qmail_external_syslog_timestamp,
		*match_qmail_new,
		*match_qmail_end,
		*match_qmail_delivery,
		*match_qmail_status,
		*match_qmail_starting,
		*match_qmail_info,
		*match_qmail_bounce,
		*match_qmail_status_smtp,
		*match_qmail_status_dsn,
		*match_qmail_triple_bounce;
} config_input;

int mplugins_input_qmail_get_next_record(mconfig *ext_conf, mlogrec *record);

#endif
